JsonField<T> class

Constructors

JsonField({required String name, required String field, String? alias, required Type fieldType, required bool fromSuper, required dynamic handler(T instance)})
const

Properties

alias → String?
final
field → String
final
fieldType → Type
final
fromSuper → bool
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
valueOf(T instance) → dynamic

Operators

operator ==(Object other) → bool
The equality operator.
inherited